import request from "@/utils/request";
// 消息模版配置表查询
export function selectMsgTmpl(data) {
    return request({
        url: "/web/msg/selectMsgTmpl",
        method: "post",
        data,
    });
}
//消息配置编辑
export function selectMsgDetl(data) {
    return request({
        url: "/web/msg/selectMsgDetl",
        method: "post",
        data,
    });
}
//消息配置保存
export function saveMsgConfig(data) {
    return request({
        url: "/web/msg/saveMsgConfig",
        method: "post",
        data,
    });
}
//消息配置下拉
export function selectListBase(data) {
    return request({
        url: "/web/msg/selectListBase",
        method: "post",
        data,
    });
}
// 消息启用禁用
export function disabMsgConfig(data) {
    return request({
        url: "/web/msg/disabMsgConfig",
        method: "post",
        data,
    });
}